==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/hu-HU/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'A felhasználó beléphet',
    'activated_disabled_help_text' => 'Saját felhasználói fiókjának a státuszát nem tudja módosítani.',
    'assets_user'       => 'Eszköz(ök) hozzárendelve: :name',
    'bulk_update_warn'	=> 'A következő felhasználók tulajdonságait szerkesztheti: user_count felhasználók. Kérjük, vegye figyelembe, hogy a saját felhasználói attribútumait nem tudja megváltoztatni ezzel az űrlappal, és személyre kell változtatni a saját felhasználóit.',
    'bulk_update_help'	=> 'Ez az űrlap egyszerre több felhasználó frissítését teszi lehetővé. Csak töltse ki a megváltoztatni kívánt mezőket. Az üresen maradt mezők változatlanok maradnak.',
    'current_assets'    => 'Az eszköz jelenleg ki van adva ennek a felhasználónak',
    'clone'             => 'Felhasználó másolása',
    'contact_user'      => 'Kapcsolattartó neve',
    'edit'              => 'Felhasználó szerkesztése',
    'filetype_info'     => 'Az engedélyezett fájltípusok png, gif, jpg, jpeg, doc, docx, pdf, txt, zip és rar.',
    'history_user'      => 'Előzmények a következőhöz: név',
    'info'				=> 'Info',
    'restore_user'		=> 'Kattintson ide a visszaállításhoz.',
    'last_login'        => 'Utolsó bejelentkezés',
    'ldap_config_text'  => 'Az LDAP konfigurációs beállításai megtalálhatók az Adminisztrálás> Beállítások menüben. Az (opcionális) kiválasztott hely minden importált felhasználó számára be lesz állítva.',
    'print_assigned'    => 'Az összes hozzárendelt nyomtatása',
    'email_assigned'    => 'A hozzárendeltek e-mail listája',
    'user_notified'     => 'A felhasználó e-mailben megkapta az aktuálisan hozzárendelt elemek listáját.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Felhasználó kihagyása a licencek automatikus hozzárendelésénél',
    'software_user'     => 'Szoftver ellenőrzése: név',
    'send_email_help'   => 'Meg kell adnod egy email címet ehhez a felhasználóhoz, hogy a hitelesítő adatok elküldve legyenek számára. Hitelesítő adatok csak a felhasználó készítésekor kerülnek elküldésre. A jelszavak hashelve kerülnek mentésre így nem lehet őket megszerezni miután elmentödtek.',
    'view_user'         => 'Felhasználó megtekintése: név',
    'usercsv'           => 'CSV fájl',
    'two_factor_admin_optin_help' => 'A jelenlegi adminisztrációs beállításai lehetővé teszik a kétütemű hitelesítés szelektív végrehajtását.',
    'two_factor_enrolled' => '2FA eszköz bejegyezve ',
    'two_factor_active'   => '2FA Aktív ',
    'user_deactivated'  => 'A felhasználó nem tud bejelentkezni',
    'user_activated'  => 'A felhasználó be tud jelentkezni',
    'activation_status_warning' => 'Ne változtassa meg az aktiválási státuszt',
    'group_memberships_helpblock' => 'Csak a szuperadminok szerkeszthetik a csoporttagságokat.',
    'superadmin_permission_warning' => 'Csak a szuperadminok adhatnak egy felhasználónak szuperadmin hozzáférést.',
    'admin_permission_warning' => 'Csak admin vagy annál nagyobb jogokkal rendelkező felhasználók adhatnak admin hozzáférést egy felhasználónak.',
    'remove_group_memberships' => 'Csoporttagságok eltávolítása',
    'warning_deletion_information' => 'Ön az alábbiakban felsorolt :count felhasználó(k) MINDEN tételét be fogja jelenteni. A szuper admin nevek pirossal vannak kiemelve.',
    'update_user_assets_status' => 'Frissítse ezen felhasználók összes eszközét erre az állapotra',
    'checkin_user_properties' => 'Ellenőrizze a felhasználókhoz kapcsolódó összes tulajdonságot',
    'remote_label'   => 'Ez egy távoli felhasználó',
    'remote'   => 'Távoli',
    'remote_help' => 'Ez akkor lehet hasznos, ha olyan távoli felhasználókra kell szűrnie, akik soha vagy ritkán járnak be a fizikai helyszínekre.',
    'not_remote_label' => 'Ez nem egy távoli felhasználó',
    'vip_label' => 'VIP felhasználó',
    'vip_help' => 'Ez hasznos lehet a fontos személyek megjelölésében, ha szeretné kölönleges módon kezelni őket.',
    'create_user' => 'Felhasználó létrehozása',
    'create_user_page_explanation' => 'Ezeket a fiókadatokat fogja tudni használni az oldal első alkalommal történő eléréséhez.',
    'email_credentials' => 'Hitelesítő adatok elküldése',
    'email_credentials_text' => 'Hitelesítő adatok elküldése a fenti címre',
    'next_save_user' => 'Következő: Felhasználó mentése',
    'all_assigned_list_generation' => 'Létrehozva:',
    'email_user_creds_on_create' => 'Elküldjük a felhasználónak a bejelentkezési adatait emailben?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/hu-HU/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'A felhasználó beléphet',
    'activated_disabled_help_text' => 'Saját felhasználói fiókjának a státuszát nem tudja módosítani.',
    'assets_user'       => 'Eszköz(ök) hozzárendelve: :name',
    'bulk_update_warn'	=> 'A következő felhasználók tulajdonságait szerkesztheti: user_count felhasználók. Kérjük, vegye figyelembe, hogy a saját felhasználói attribútumait nem tudja megváltoztatni ezzel az űrlappal, és személyre kell változtatni a saját felhasználóit.',
    'bulk_update_help'	=> 'Ez az űrlap egyszerre több felhasználó frissítését teszi lehetővé. Csak töltse ki a megváltoztatni kívánt mezőket. Az üresen maradt mezők változatlanok maradnak.',
    'current_assets'    => 'Az eszköz jelenleg ki van adva ennek a felhasználónak',
    'clone'             => 'Felhasználó másolása',
    'contact_user'      => 'Kapcsolattartó neve',
    'edit'              => 'Felhasználó szerkesztése',
    'filetype_info'     => 'Az engedélyezett fájltípusok png, gif, jpg, jpeg, doc, docx, pdf, txt, zip és rar.',
    'history_user'      => 'Előzmények a következőhöz: név',
    'info'				=> 'Info',
    'restore_user'		=> 'Kattintson ide a visszaállításhoz.',
    'last_login'        => 'Utolsó bejelentkezés',
    'ldap_config_text'  => 'Az LDAP konfigurációs beállításai megtalálhatók az Adminisztrálás> Beállítások menüben. Az (opcionális) kiválasztott hely minden importált felhasználó számára be lesz állítva.',
    'print_assigned'    => 'Az összes hozzárendelt nyomtatása',
    'email_assigned'    => 'A hozzárendeltek e-mail listája',
    'user_notified'     => 'A felhasználó e-mailben megkapta az aktuálisan hozzárendelt elemek listáját.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Felhasználó kihagyása a licencek automatikus hozzárendelésénél',
    'software_user'     => 'Szoftver ellenőrzése: név',
    'send_email_help'   => 'Meg kell adnod egy email címet ehhez a felhasználóhoz, hogy a hitelesítő adatok elküldve legyenek számára. Hitelesítő adatok csak a felhasználó készítésekor kerülnek elküldésre. A jelszavak hashelve kerülnek mentésre így nem lehet őket megszerezni miután elmentödtek.',
    'view_user'         => 'Felhasználó megtekintése: név',
    'usercsv'           => 'CSV fájl',
    'two_factor_admin_optin_help' => 'A jelenlegi adminisztrációs beállításai lehetővé teszik a kétütemű hitelesítés szelektív végrehajtását.',
    'two_factor_enrolled' => '2FA eszköz bejegyezve ',
    'two_factor_active'   => '2FA Aktív ',
    'user_deactivated'  => 'A felhasználó nem tud bejelentkezni',
    'user_activated'  => 'A felhasználó be tud jelentkezni',
    'activation_status_warning' => 'Ne változtassa meg az aktiválási státuszt',
    'group_memberships_helpblock' => 'Csak a szuperadminok szerkeszthetik a csoporttagságokat.',
    'superadmin_permission_warning' => 'Csak a szuperadminok adhatnak egy felhasználónak szuperadmin hozzáférést.',
    'admin_permission_warning' => 'Csak admin vagy annál nagyobb jogokkal rendelkező felhasználók adhatnak admin hozzáférést egy felhasználónak.',
    'remove_group_memberships' => 'Csoporttagságok eltávolítása',
    'warning_deletion_information' => 'Ön az alábbiakban felsorolt :count felhasználó(k) MINDEN tételét be fogja jelenteni. A szuper admin nevek pirossal vannak kiemelve.',
    'update_user_assets_status' => 'Frissítse ezen felhasználók összes eszközét erre az állapotra',
    'checkin_user_properties' => 'Ellenőrizze a felhasználókhoz kapcsolódó összes tulajdonságot',
    'remote_label'   => 'Ez egy távoli felhasználó',
    'remote'   => 'Távoli',
    'remote_help' => 'Ez akkor lehet hasznos, ha olyan távoli felhasználókra kell szűrnie, akik soha vagy ritkán járnak be a fizikai helyszínekre.',
    'not_remote_label' => 'Ez nem egy távoli felhasználó',
    'vip_label' => 'VIP felhasználó',
    'vip_help' => 'Ez hasznos lehet a fontos személyek megjelölésében, ha szeretné kölönleges módon kezelni őket.',
    'create_user' => 'Felhasználó létrehozása',
    'create_user_page_explanation' => 'Ezeket a fiókadatokat fogja tudni használni az oldal első alkalommal történő eléréséhez.',
    'email_credentials' => 'Hitelesítő adatok elküldése',
    'email_credentials_text' => 'Hitelesítő adatok elküldése a fenti címre',
    'next_save_user' => 'Következő: Felhasználó mentése',
    'all_assigned_list_generation' => 'Létrehozva:',
    'email_user_creds_on_create' => 'Elküldjük a felhasználónak a bejelentkezési adatait emailben?',
];
